==> gpfs-2.2.0-1.i386.update.tar.gz: usr/lpp/mmfs/src/gpl-linux/mmfsmod.c <==
/***************************************************************************
 *
 * Copyright (C) 2001 International Business Machines
 * All rights reserved.
 *
 * This file is part of the GPFS mmfslinux kernel module.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer. 
 *  2. Redistributions in binary form must reproduce the above copyright 
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution. 
 *  3. The name of the author may not be used to endorse or promote products 
 *     derived from this software without specific prior written
 *     permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************** */
static char sccsid[] = "@(#)45	1.1  src/avs/fs/mmfs/ts/kernext/gpl-linux/mmfsmod.c, mmfs, avs_rcs2b, rcs2b0344a 1/20/03 16:12:01";

/* A file shipped with the portability layer that is
 * compiled and linked with the mmfs module (non portability
 * layer).   Used so that struct module can be included and 
 * compiled according to the customer's kernel configuration.
 * The mmfs module is not dependent on anything else in the 
 * kernel except for this struct module silliness.
 */

#if LINUX_KERNEL_VERSION >= 2050000

/* mmfs module initialization for 2.5 */
#define KBUILD_MODNAME mmfs

#include <linux/module.h>
#include <linux/init.h>

extern int ibm_init();
extern void ibm_cleanup();

static int __init
modInit(void)
{
  return ibm_init();
}

static void __exit
modExit(void)
{
  ibm_cleanup();
}

module_init(modInit);
module_exit(modExit);
#endif

==> gpfs-2.2.1-4.i386.update.tar.gz: usr/lpp/mmfs/src/gpl-linux/mmfsmod.c <==
/***************************************************************************
 *
 * Copyright (C) 2001 International Business Machines
 * All rights reserved.
 *
 * This file is part of the GPFS mmfslinux kernel module.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer. 
 *  2. Redistributions in binary form must reproduce the above copyright 
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution. 
 *  3. The name of the author may not be used to endorse or promote products 
 *     derived from this software without specific prior written
 *     permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************** */
static char sccsid[] = "@(#)45	1.1  src/avs/fs/mmfs/ts/kernext/gpl-linux/mmfsmod.c, mmfs, avs_rcs2b, rcs2bs001a 1/20/03 16:12:01";

/* A file shipped with the portability layer that is
 * compiled and linked with the mmfs module (non portability
 * layer).   Used so that struct module can be included and 
 * compiled according to the customer's kernel configuration.
 * The mmfs module is not dependent on anything else in the 
 * kernel except for this struct module silliness.
 */

#if LINUX_KERNEL_VERSION >= 2050000

/* mmfs module initialization for 2.5 */
#define KBUILD_MODNAME mmfs

#include <linux/module.h>
#include <linux/init.h>

extern int ibm_init();
extern void ibm_cleanup();

static int __init
modInit(void)
{
  return ibm_init();
}

static void __exit
modExit(void)
{
  ibm_cleanup();
}

module_init(modInit);
module_exit(modExit);
#endif
